=====================
Configuration Options
=====================

This section provides a list of all possible options for each
configuration file.
These are generated from code and reflect the current state of code
in the networking-bgpvpn repository.

Configuration Reference
-----------------------

networking-bgpvpn uses the following configuration files for its
various services.

.. toctree::
   :glob:
   :maxdepth: 1

   *

Sample Configuration Files
--------------------------

The following are sample configuration files for all networking-bgpvpn.

.. toctree::
   :glob:
   :maxdepth: 1

   samples/*
